PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Util/PCBItemSets.hpp File Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Structures | Namespaces | Functions
PCBItemSets.hpp File Reference
`#include "Py.hpp"`
`#include <set>`

Go to the source code of this file.

## Data Structures
struct | PCBItemSets

## Namespaces
namespace | util

## Functions
void | util::populate (std::set< Connection * > &, PCBoard &, PyObject *)
void | util::populate (std::set< Net * > &, PCBoard &, PyObject *)
void | util::populate (std::set< Component * > &, PCBoard &, PyObject *)
void | util::populate (std::set< Pin * > &, PCBoard &, PyObject *)